/*
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.amdatu.security.tokenprovider.tests;

import static org.amdatu.testing.configurator.TestConfigurator.cleanUp;
import static org.amdatu.testing.configurator.TestConfigurator.configure;
import static org.amdatu.testing.configurator.TestConfigurator.createConfiguration;
import static org.amdatu.testing.configurator.TestConfigurator.createServiceDependency;
import static org.junit.Assert.assertEquals;
import static org.mockito.Matchers.anyString;
import static org.mockito.Mockito.mock;
import static org.mockito.Mockito.when;

import java.util.SortedMap;
import java.util.TreeMap;

import org.amdatu.security.tokenprovider.TokenProvider;
import org.amdatu.security.tokenprovider.TokenStorageProvider;
import org.junit.After;
import org.junit.Before;
import org.junit.Test;
import org.osgi.framework.BundleContext;
import org.osgi.framework.FrameworkUtil;

public class TokenProviderTest {
	private volatile TokenProvider m_TokenProvider;
	private final BundleContext context = FrameworkUtil.getBundle(this.getClass()).getBundleContext();
	
	
	@Before
    public void setUp() throws Exception {
		
		TokenStorageProvider tokenStorageProviderMock = mock(TokenStorageProvider.class);
    	when(tokenStorageProviderMock.hasToken(anyString())).thenReturn(true);
    	
    	context.registerService(TokenStorageProvider.class.getName(), tokenStorageProviderMock, null);
		
		configure(this)
			.add(createServiceDependency().setService(TokenProvider.class).setRequired(true))
			.add(createConfiguration(TokenProvider.PID).set("secretkey", "[randomkey]"))
			.apply();
		
    }

	@Test
    public void testGenerateToken() throws Exception {
    	
    	SortedMap<String, String> attributes = new TreeMap<>();
    	attributes.put(TokenProvider.USERNAME, "testuser");
    	attributes.put("someotherkey", "somevalue");
    	
    	String token = m_TokenProvider.generateToken(attributes);
    	
    	SortedMap<String, String> verified = m_TokenProvider.verifyToken(token);
    	assertEquals(verified.get(TokenProvider.USERNAME), "testuser");
    	assertEquals(verified.get("someotherkey"), "somevalue");
    }
	
	@After
	public void cleanup() {
		cleanUp(this);
	}
}
